from stringcolor import * 

def test():
  print(cs("you good", "#0000ff"))